/*
 *
 *  Linux HardSID Ioctl calls
 *
 *  Copyright (C) 2001-2002 Jarno Paananen <jpaana@s2.org>
 *  Copyright (C) 2001      Simon White    <s_a_white@email.com>
 *
 *      This program is free software; you can redistribute it and/or
 *      modify it under the terms of the GNU General Public License
 *      as published by the Free Software Foundation; either version
 *      2 of the License, or (at your option) any later version.
 *
 */

#ifndef _hardsid_h_
#define _hardsid_h_

#ifdef __KERNEL__
#   include <linux/ioctl.h>
#else
#   include <sys/ioctl.h>
#endif

/* HSID_IOCTL_SIDTYPE - Sid type enum */
typedef enum
{
    SID_NONE = 0,
    SID_6581,
    SID_8580
} sid_type;

/* HSID_IOCTL_CARDTYPE - Card type enum */
typedef enum
{
    SID_CARD_NONE = 0,
    SID_CARD_HARDSID,
    SID_CARD_QUATTRO,
    SID_CARD_CWMK3,
    SID_CARD_PCI_HARDSID,
    SID_CARD_PCI_QUATTRO,
    SID_CARD_CWMK4
} sid_card_type;

/* For use with read/write calls (and HSID_IOCTL_READ)
 * where the sid id is optional
 */
#define HSID_SID_ID_PRESENT 0x2000

/* The ioctls we use */
#define HSID_IOCTL_RESET     _IOW('S', 0, int)
#define HSID_IOCTL_RELEASE   _IO ('S', 2)
#define HSID_IOCTL_SIDTYPE   _IOWR('S', 3, int)
#define HSID_IOCTL_MUTE      _IOW('S', 5, int)
#define HSID_IOCTL_NOFILTER  _IOW('S', 6, int)
#define HSID_IOCTL_FLUSH     _IO ('S', 7)
#define HSID_IOCTL_DELAY     _IOW('S', 8, int)
#define HSID_IOCTL_READ      _IOWR('S', 9, int*)
#define HSID_IOCTL_FIFOFREE  _IOR('S', 10, int)

#define HSID_IOCTL_DEVICES   _IOR('S', 100, int)
#define HSID_IOCTL_ALLOCATE  _IOWR('S', 102, int)
#define HSID_IOCTL_FIFOSIZE  _IOR('S', 101, int)
#define HSID_IOCTL_ALLOCATED _IOR('S', 104, int)

#endif /* _hardsid_h_ */
